exceptiontools.VoiceContainmentError
====================================

.. inheritance-diagram:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
